summaryrefslogtreecommitdiff
path: root/examples/stokes_drag_particle_2d_psm_gpu/sim.cpp
diff options
context:
space:
mode:
authorClaudius "keldu" Holeksa <mail@keldu.de>2026-07-08 11:15:16 +0200
committerClaudius "keldu" Holeksa <mail@keldu.de>2026-07-08 11:15:16 +0200
commit34f0ae814604aa31524dbc2a9bef97ce54f1fb14 (patch)
tree28ddf06c4c27f7f1604c637bfe6cfab2ba32fc38 /examples/stokes_drag_particle_2d_psm_gpu/sim.cpp
parent3cf348cdbbc2ce7f2e29c43771e6ea7e773d6347 (diff)
parent5437a8e0c730cbee5bceb93915d1df36776d210d (diff)
downloadlibs-lbm-34f0ae814604aa31524dbc2a9bef97ce54f1fb14.tar.gz
Merge branch 'dev'
Diffstat (limited to 'examples/stokes_drag_particle_2d_psm_gpu/sim.cpp')
-rw-r--r--examples/stokes_drag_particle_2d_psm_gpu/sim.cpp17
1 files changed, 3 insertions, 14 deletions
diff --git a/examples/stokes_drag_particle_2d_psm_gpu/sim.cpp b/examples/stokes_drag_particle_2d_psm_gpu/sim.cpp
index 9d678a8..e4f468c 100644
--- a/examples/stokes_drag_particle_2d_psm_gpu/sim.cpp
+++ b/examples/stokes_drag_particle_2d_psm_gpu/sim.cpp
@@ -202,19 +202,8 @@ saw::error_or<void> step(
return vel;
}()
};
- component<T,Desc,cmpt::ZouHeVelocityX<false>,encode::Sycl<saw::encode::Native>> flow_out{
- [&]() -> saw::data<sch::Vector<T,Desc::D>>{
- saw::data<sch::Vector<T,Desc::D>> vel;
- uint64_t target_t_i = 8u;
- if(t_i.get() < target_t_i){
- vel.at({{0u}}) = (0.0002 / target_t_i) * t_i.get();
- }else{
- vel.at({{0u}}) = 0.0002;
- }
- return vel;
- }()
- };
-
+ component<T,Desc,cmpt::ZouHeHorizontal<false>,encode::Sycl<saw::encode::Native>> flow_out{1.0};
+
component<T,Desc,cmpt::ForceGather, encode::Sycl<saw::encode::Native>> fg;
h.parallel_for(acpp::sycl::range<Desc::D>{dim_x,dim_y}, [=](acpp::sycl::id<Desc::D> idx){
@@ -360,7 +349,7 @@ saw::error_or<void> lbm_main(int argc, char** argv){
auto lsd_view = make_view(lbm_sycl_data);
auto lsdm_view = make_view(lbm_sycl_macro_data);
- saw::data<sch::UInt64> time_steps{32u*4096ul};
+ saw::data<sch::UInt64> time_steps{64u*4096ul};
auto& info_f = lsd_view.template get<"info">();